@@ -42,9 +42,9 @@ class FontColourButton : public PushButton
         QFont         font() const           { return mFont; }
         QColor        bgColour() const       { return mBgColour; }
         QColor        fgColour() const       { return mFgColour; }
-        void          setReadOnly(bool ro, bool noHighlight = false) Q_DECL_OVERRIDE
+        void          setReadOnly(bool ro, bool noHighlight = false) override
                                  { mReadOnly = ro; PushButton::setReadOnly(ro, noHighlight); }
-        bool          isReadOnly() const Q_DECL_OVERRIDE     { return mReadOnly; }
+        bool          isReadOnly() const override     { return mReadOnly; }
 
     Q_SIGNALS:
         /** Signal emitted whenever a font or colour has been selected. */
